# "docwarrior" concept

"docwarrior" concept following the principles of task/time/bugwarrior and __Linked Data__ for cross-referencing.

In all cases it is necessary to ensure that documents are findable, accessible, and interoperable.
This is ensured by maintaining bidirectional references with suitable metadata for all developments and activities.

## Tools

https://github.com/volodymyrss/confluence-offline

https://github.com/volodymyrss/redmine-flow

gitlab, github as desired

overleaf/sharelatex through git and api for comments
